/*
Author:
Sreekumar Thaithara Balan 

Name:
desity.cc

Version:
0.7

Last modified:
30-03-2008

Purpose:
1. Impelments the following prior densities
   a. Uniform Prior
   b. Jeffreys Prior
   c. Modified Jeffreys Prior

Implements:
1. Uniform::probability()->density.h
2. Jeffreys::probability()->density.h
3. Modified_jeffreys::probability()->density.h
4. Gsussian::likelihood()->density.h

Todo:
1. Modify the sigma_search to Harrio et all 2003 method

References:
1. Rosentahl
2. H. Harrio, E. Saksman and J. Tamminen,

License:
GNU General Public License
This file is part of Exofit.

Exofit is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

Exofit is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Exofit; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
Boston, MA 02110-1301, USA.

*/

#include<cmath>
#include"data.h"
#include"density.h"
#include"radial_v.h"

double Uniform::probability()
{
  return log(1/(max-min));
}
double Jeffreys::probability()
{
  return log(1/(val*log(max/min)));
}

double Modified_jeffreys::probability()
{
  return log(1/((val+BREAK)*log((BREAK+max)/BREAK)));
}

double N_planet_Gaussian::likelihood()
{

  if(par.size()==n_pla*5+2)
    {
      int n_entries=input_data->get_n_entries();
      double resid=0;
      double chi_2=0;
      double constant_A=1;
      double l_lik=0;
      double noise=par[par.size()-1];

      for(int k=0;k<n_entries;++k)
	{
	  double sigma=input_data->get_data_entry(k,2);
	  double tmp=1/sqrt(2*M_PI*(sigma*sigma+noise*noise));
	  constant_A=constant_A*tmp;
	}
      for(int i=0;i<n_entries;++i)
	{
	  double time=input_data->get_data_entry(i,0);
	  double velocity=input_data->get_data_entry(i,1);
	  double sigma=input_data->get_data_entry(i,2);

	  double rad_v=Suto::rad_v(time,par,n_pla);

	  resid=(velocity-rad_v)*(velocity-rad_v)/(sigma*sigma+noise*noise);
	  chi_2=chi_2+resid;
	}
      l_lik=log(constant_A)-0.5*chi_2; // log (exp(-X/2))=-X/2
      return l_lik;
    }
  else
    {
      std::cout<<"Number of parameters does not match the number of planets\n";
      return -400;// check this
    }
}
